@@ -9,16 +9,18 @@ library(imagine)
 #  # Kernel 1: For bottom edge recognition
 #  kernel1 <- matrix(c(-1, -2, -1,
 #                       0,  0,  0,
-#                       1,  2,  1), nrow = 3)
+#                       1,  2,  1),
+#                    nrow = 3)
 #  
 #  # Kernel 2: Diagonal weighting
-#  kernel2 <- matrix(c(1, 0, 1,
-#                      0, 2, 0,
-#                      1, 0, 1), nrow = 3)
+#  kernel2 <- matrix(c(-2, 0, 0,
+#                       0, 1, 0,
+#                       0, 0, 2),
+#                    nrow = 3)
 #  
 #  # Apply filters
 #  convolutionExample  <- convolution2D(dataMatrix = wbImage, kernel = kernel1)
-#  convQuantileExample <- convolutionQuantile(dataMatrix = wbImage, kernel = kernel2, x = 0.7)
+#  convQuantileExample <- convolutionQuantile(dataMatrix = wbImage, kernel = kernel2, x = 0.1)
 #  
 
 ## ---- message=FALSE, fig.height=3, fig.width=5.33, fig.cap = "Figure 2: Original matrix", results='hide', fig.pos="h", echo=FALSE----
@@ -35,27 +37,27 @@ myMatrix <- wbImage
 # Kernel 1: For bottom edge recognition
 kernel1 <- matrix(c(-1, -2, -1,
                      0,  0,  0,
-                     1,  2,  1), nrow = 3)
+                     1,  2,  1), 
+                  nrow = 3)
 
 # Kernel 2: Diagonal weighting
-kernel2 <- matrix(c(1, 2, 1,
-                    2, 4, 2,
-                    1, 2, 1), nrow = 3)
+kernel2 <- matrix(c(-2, 0, 0,
+                    0, 1, 0,
+                    0, 0, 2), 
+                  nrow = 3)
 
 # Apply filters
 convolutionExample  <- convolution2D(dataMatrix = myMatrix, kernel = kernel1)
-convQuantileExample <- convolutionQuantile(dataMatrix = myMatrix, kernel = kernel2, x = 0.7)
+convQuantileExample <- convolutionQuantile(dataMatrix = myMatrix, kernel = kernel2, x = 0.1)
 
 # Make plots
 par(mar = c(0, 0.5, 0, 0.5), oma = c(0, 0, 2, 0), mfrow = c(2, 1))
 
-convolutionExample[convolutionExample < 0] <- 0
 image(convolutionExample, col = cols, axes = FALSE)
 mtext(text = "2D convolution", side = 1, line = -1.5, col = "white", font = 2, adj = 0.99)
 
-convQuantileExample[convQuantileExample < 0] <- 0
 image(convQuantileExample, col = cols, axes = FALSE)
-mtext(text = "2D median convolution", side = 1, line = -1.5, col = "white", font = 2, adj = 0.99)
+mtext(text = "2D quantile convolution", side = 1, line = -1.5, col = "white", font = 2, adj = 0.99)
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  # Add some noise (NA) to the image (matrix)
@@ -69,7 +71,7 @@ mtext(text = "2D median convolution", side = 1, line = -1.5, col = "white", font
 #  # Apply filters
 #  meanfilterExample     <- meanFilter(dataMatrix = myMatrix, radius = radius)
 #  quantilefilterExample <- quantileFilter(dataMatrix = myMatrix, radius = radius, x = 0.1)
-#  medianfilterExample   <- medianFilter(dataMatrix = myMatrix, radius = radius)
+#  medianfilterExample   <- medianFilter(dataMatrix = myMatrix, radius = radius, times = 10)
 #  
 
 ## ---- message=FALSE, fig.height=3, fig.width=5.33, fig.cap = "Figure 2: Original matrix", results='hide', fig.pos="h", echo=FALSE----
@@ -95,20 +97,20 @@ radius <- 3
 # Apply filters
 meanfilterExample     <- meanFilter(dataMatrix = myMatrix, radius = radius)
 quantilefilterExample <- quantileFilter(dataMatrix = myMatrix, radius = radius, x = 0.1)
-medianfilterExample   <- medianFilter(dataMatrix = myMatrix, radius = radius)
+medianfilterExample   <- medianFilter(dataMatrix = myMatrix, radius = radius, times = 10)
 
 # Make plots
 par(mar = c(0, 0.5, 0, 0.5), oma = c(0, 0, 2, 0), mfrow = c(3, 1))
 
-meanfilterExample[meanfilterExample < 0] <- 0
+# meanfilterExample[meanfilterExample < 0] <- 0
 image(meanfilterExample, col = cols, axes = FALSE)
 mtext(text = "Mean filter", side = 1, line = -1.5, col = "white", font = 2, adj = 0.99)
 
-quantilefilterExample[quantilefilterExample < 0] <- 0
+# quantilefilterExample[quantilefilterExample < 0] <- 0
 image(quantilefilterExample, col = cols, axes = FALSE)
 mtext(text = "Quantile filter", side = 1, line = -1.5, col = "white", font = 2, adj = 0.99)
 
-medianfilterExample[medianfilterExample < 0] <- 0
+# medianfilterExample[medianfilterExample < 0] <- 0
 image(medianfilterExample, col = cols, axes = FALSE)
 mtext(text = "2D median filter", side = 1, line = -1.5, col = "white", font = 2, adj = 0.99)
 
